# khufu

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/khufu)](https://pypi.org/project/khufu/)  
[![](https://img.shields.io/pypi/v/khufu)](https://pypi.org/project/khufu/)  
[![](https://img.shields.io/github/license/thespacedoctor/khufu)](https://github.com/thespacedoctor/khufu)  
[![](https://img.shields.io/pypi/dm/khufu)](https://pypi.org/project/khufu/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=khufu%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/khufu/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=khufu%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/khufu/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/khufu@master/coverage.svg)](https://raw.githack.com/thespacedoctor/khufu/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/khufu/badge/?version=master)](https://khufu.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/khufu/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/khufu/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Twitter Bootstrap elements via Python*.

Documentation for khufu is hosted by [Read the Docs](https://khufu.readthedocs.io/en/master/) (
[development version](https://khufu.readthedocs.io/en/develop/) and [master version](https://khufu.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/khufu). Please report any issues you find [here](https://github.com/thespacedoctor/khufu/issues).

## Features

* 



